@@ -4,7 +4,7 @@ require File.join(File.dirname(__FILE__), "account_control")
 
 Plugin.create :change_account do
   # トークン切れの警告
-  MikuTwitter::AuthenticationFailedAction.regist do |service, method = nil, url = nil, options = nil, res = nil|
+  MikuTwitter::AuthenticationFailedAction.register do |service, method = nil, url = nil, options = nil, res = nil|
     activity(:system, _("アカウントエラー (@{user})", user: service.user),
              description: _("ユーザ @{user} のOAuth 認証が失敗しました (@{response})\n設定から、認証をやり直してください。",
                             user: service.user, response: res))
