@@ -345,10 +345,14 @@ Plugin.create :gtk do
   on_gui_timeline_set_order do |i_timeline, order|
     widgetof(i_timeline).set_order(&order) end
 
-  filter_gui_timeline_has_messages do |i_timeline, messages|
+  filter_gui_timeline_select_messages do |i_timeline, messages|
     [i_timeline,
      messages.select(&widgetof(i_timeline).method(:include?))] end
 
+  filter_gui_timeline_reject_messages do |i_timeline, messages|
+    [i_timeline,
+     messages.reject(&widgetof(i_timeline).method(:include?))] end
+
   on_gui_postbox_post do |i_postbox|
     postbox = widgetof(i_postbox)
     if postbox
@@ -502,9 +506,10 @@ Plugin.create :gtk do
     pane = widgetof(i_pane)
     return false if not pane
     is_tab = i_tab.is_a?(Plugin::GUI::Tab)
-    is_parmatab = is_tab and not(i_tab.temporary_tab?)
-    has_child = is_parmatab and not(i_tab.children.any?{ |child|
-                                      not child.is_a? Plugin::GUI::TabToolbar })
+    has_child = is_tab and
+      not(i_tab.temporary_tab?) and
+      not(i_tab.children.any?{ |child|
+            not child.is_a? Plugin::GUI::TabToolbar })
     notice "widget_join_tab: #{widget} join #{i_tab}"
     if has_child
       Plugin.call(:rewind_window_order, i_pane.parent) end
